@@ -15,11 +15,11 @@ class PathValues(str, enum.Enum):
     V1_INGEST_DOCUMENT_DOCUMENT_ID = "/v1/ingest/document/{documentId}"
     V1_SEARCH_ID = "/v1/search/{id}"
     V1_SEARCH_DOCUMENTS = "/v1/search/documents"
-    V1_PROJECT = "/v1/project"
-    V1_PROJECT_PROJECT_ID = "/v1/project/{projectId}"
-    V1_PROJECT_PROJECT_ID_BUCKET_BUCKET_ID = "/v1/project/{projectId}/bucket/{bucketId}"
     V1_BUCKET = "/v1/bucket"
     V1_BUCKET_BUCKET_ID = "/v1/bucket/{bucketId}"
+    V1_GROUP = "/v1/group"
+    V1_GROUP_GROUP_ID = "/v1/group/{groupId}"
+    V1_GROUP_GROUP_ID_BUCKET_BUCKET_ID = "/v1/group/{groupId}/bucket/{bucketId}"
     V1_CUSTOMER = "/v1/customer"
     V1_HEALTH = "/v1/health"
     V1_HEALTH_SERVICE = "/v1/health/{service}"
